@@ -19,15 +19,6 @@
 # flake8: noqa
 import sys
 from paramiko._version import __version__, __version_info__
-
-if sys.version_info < (2, 6):
-    raise RuntimeError("You need Python 2.6+ for this module.")
-
-
-__author__ = "Jeff Forcier <jeff@bitprophet.org>"
-__license__ = "GNU Lesser General Public License (LGPL)"
-
-
 from paramiko.transport import SecurityOptions, Transport
 from paramiko.client import (
     SSHClient,
@@ -38,7 +29,7 @@ from paramiko.client import (
 )
 from paramiko.auth_handler import AuthHandler
 from paramiko.ssh_gss import GSSAuth, GSS_AUTH_AVAILABLE, GSS_EXCEPTIONS
-from paramiko.channel import Channel, ChannelFile
+from paramiko.channel import Channel, ChannelFile, ChannelStderrFile
 from paramiko.ssh_exception import (
     SSHException,
     PasswordRequiredException,
@@ -94,42 +85,46 @@ from paramiko.sftp import (
 
 from paramiko.common import io_sleep
 
+
+__author__ = "Jeff Forcier <jeff@bitprophet.org>"
+__license__ = "GNU Lesser General Public License (LGPL)"
+
 __all__ = [
-    "Transport",
-    "SSHClient",
-    "MissingHostKeyPolicy",
-    "AutoAddPolicy",
-    "RejectPolicy",
-    "WarningPolicy",
-    "SecurityOptions",
-    "SubsystemHandler",
-    "Channel",
-    "PKey",
-    "RSAKey",
-    "DSSKey",
-    "Message",
-    "SSHException",
-    "AuthenticationException",
-    "PasswordRequiredException",
-    "BadAuthenticationType",
-    "ChannelException",
-    "BadHostKeyException",
-    "ProxyCommand",
-    "ProxyCommandFailure",
-    "SFTP",
-    "SFTPFile",
-    "SFTPHandle",
-    "SFTPClient",
-    "SFTPServer",
-    "SFTPError",
-    "SFTPAttributes",
-    "SFTPServerInterface",
-    "ServerInterface",
-    "BufferedFile",
     "Agent",
     "AgentKey",
+    "AuthenticationException",
+    "AutoAddPolicy",
+    "BadAuthenticationType",
+    "BadHostKeyException",
+    "BufferedFile",
+    "Channel",
+    "ChannelException",
+    "DSSKey",
     "HostKeys",
+    "Message",
+    "MissingHostKeyPolicy",
+    "PKey",
+    "PasswordRequiredException",
+    "ProxyCommand",
+    "ProxyCommandFailure",
+    "RSAKey",
+    "RejectPolicy",
+    "SFTP",
+    "SFTPAttributes",
+    "SFTPClient",
+    "SFTPError",
+    "SFTPFile",
+    "SFTPHandle",
+    "SFTPServer",
+    "SFTPServerInterface",
+    "SSHClient",
     "SSHConfig",
-    "util",
+    "SSHException",
+    "SecurityOptions",
+    "ServerInterface",
+    "SubsystemHandler",
+    "Transport",
+    "WarningPolicy",
     "io_sleep",
+    "util",
 ]
