@@ -145,7 +145,7 @@ class Channel(ClosingContextManager):
         """
         Return a string representation of this object, for debugging.
         """
-        out = "<paramiko.Channel %d" % self.chanid
+        out = "<paramiko.Channel {}".format(self.chanid)
         if self.closed:
             out += " (closed)"
         elif self.active:
@@ -153,9 +153,9 @@ class Channel(ClosingContextManager):
                 out += " (EOF received)"
             if self.eof_sent:
                 out += " (EOF sent)"
-            out += " (open) window=%d" % self.out_window_size
+            out += " (open) window={}".format(self.out_window_size)
             if len(self.in_buffer) > 0:
-                out += " in-buffer=%d" % (len(self.in_buffer),)
+                out += " in-buffer={}".format(len(self.in_buffer))
         out += " -> " + repr(self.transport)
         out += ">"
         return out
@@ -331,7 +331,7 @@ class Channel(ClosingContextManager):
             try:
                 self.set_environment_variable(name, value)
             except SSHException as e:
-                err = 'Failed to set environment variable "{0}".'
+                err = 'Failed to set environment variable "{}".'
                 raise SSHException(err.format(name), e)
 
     @open_only
@@ -991,7 +991,7 @@ class Channel(ClosingContextManager):
         # a window update
         self.in_window_threshold = window_size // 10
         self.in_window_sofar = 0
-        self._log(DEBUG, "Max packet in: %d bytes" % max_packet_size)
+        self._log(DEBUG, "Max packet in: {} bytes".format(max_packet_size))
 
     def _set_remote_channel(self, chanid, window_size, max_packet_size):
         self.remote_chanid = chanid
@@ -1000,10 +1000,12 @@ class Channel(ClosingContextManager):
             max_packet_size
         )
         self.active = 1
-        self._log(DEBUG, "Max packet out: %d bytes" % self.out_max_packet_size)
+        self._log(
+            DEBUG, "Max packet out: {} bytes".format(self.out_max_packet_size)
+        )
 
     def _request_success(self, m):
-        self._log(DEBUG, "Sesch channel %d request ok" % self.chanid)
+        self._log(DEBUG, "Sesch channel {} request ok".format(self.chanid))
         self.event_ready = True
         self.event.set()
         return
@@ -1031,7 +1033,7 @@ class Channel(ClosingContextManager):
         s = m.get_binary()
         if code != 1:
             self._log(
-                ERROR, "unknown extended_data type %d; discarding" % code
+                ERROR, "unknown extended_data type {}; discarding".format(code)
             )
             return
         if self.combine_stderr:
@@ -1044,7 +1046,7 @@ class Channel(ClosingContextManager):
         self.lock.acquire()
         try:
             if self.ultra_debug:
-                self._log(DEBUG, "window up %d" % nbytes)
+                self._log(DEBUG, "window up {}".format(nbytes))
             self.out_window_size += nbytes
             self.out_buffer_cv.notifyAll()
         finally:
@@ -1131,7 +1133,7 @@ class Channel(ClosingContextManager):
             else:
                 ok = server.check_channel_forward_agent_request(self)
         else:
-            self._log(DEBUG, 'Unhandled channel request "%s"' % key)
+            self._log(DEBUG, 'Unhandled channel request "{}"'.format(key))
             ok = False
         if want_reply:
             m = Message()
@@ -1153,7 +1155,7 @@ class Channel(ClosingContextManager):
                     self._pipe.set_forever()
         finally:
             self.lock.release()
-        self._log(DEBUG, "EOF received (%s)", self._name)
+        self._log(DEBUG, "EOF received ({})".format(self._name))
 
     def _handle_close(self, m):
         self.lock.acquire()
@@ -1225,7 +1227,7 @@ class Channel(ClosingContextManager):
         m.add_byte(cMSG_CHANNEL_EOF)
         m.add_int(self.remote_chanid)
         self.eof_sent = True
-        self._log(DEBUG, "EOF sent (%s)", self._name)
+        self._log(DEBUG, "EOF sent ({})".format(self._name))
         return m
 
     def _close_internal(self):
@@ -1259,12 +1261,14 @@ class Channel(ClosingContextManager):
             if self.closed or self.eof_received or not self.active:
                 return 0
             if self.ultra_debug:
-                self._log(DEBUG, "addwindow %d" % n)
+                self._log(DEBUG, "addwindow {}".format(n))
             self.in_window_sofar += n
             if self.in_window_sofar <= self.in_window_threshold:
                 return 0
             if self.ultra_debug:
-                self._log(DEBUG, "addwindow send %d" % self.in_window_sofar)
+                self._log(
+                    DEBUG, "addwindow send {}".format(self.in_window_sofar)
+                )
             out = self.in_window_sofar
             self.in_window_sofar = 0
             return out
@@ -1307,7 +1311,7 @@ class Channel(ClosingContextManager):
             size = self.out_max_packet_size - 64
         self.out_window_size -= size
         if self.ultra_debug:
-            self._log(DEBUG, "window down to %d" % self.out_window_size)
+            self._log(DEBUG, "window down to {}".format(self.out_window_size))
         return size
 
 
@@ -1344,15 +1348,9 @@ class ChannelFile(BufferedFile):
 
 
 class ChannelStderrFile(ChannelFile):
-    def __init__(self, channel, mode="r", bufsize=-1):
-        ChannelFile.__init__(self, channel, mode, bufsize)
-
     def _read(self, size):
         return self.channel.recv_stderr(size)
 
     def _write(self, data):
         self.channel.sendall_stderr(data)
         return len(data)
-
-
-# vim: set shiftwidth=4 expandtab :
